@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/mydb_db3.c,v 1.8 2008/06/03 10:02:57 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/mydb_db3.c,v 1.10 2008/06/24 15:31:21 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -208,7 +208,11 @@ static int init(const char *dbdir, int myflags)
   if (!(r = myinit(dbdir, myflags)))
     return(0);
 
-  if (r != ENOENT) {
+  if (r != ENOENT
+#ifdef DB_VERSION_MISMATCH
+      && r != DB_VERSION_MISMATCH
+#endif
+      ) {
     log_panic("DBERROR: dbenv->open '%s' failed: %s", dbdir, db_strerror(r));
     return MYDB_IOERROR;
   }
@@ -217,7 +221,7 @@ static int init(const char *dbdir, int myflags)
   /* DPC 24/03/2002.  DB_CREATE leaks 12 MBytes into dbenv.
    * Workaround: close down dbenv, reopen after backing files created */
      
-  r = myinit(dbdir, myflags|MYDB_CREATE);
+  r = myinit(dbdir, myflags|MYDB_CREATE|MYDB_RECOVER);
   if (r) {
     log_panic("DBERROR: dbenv->open '%s' failed: %s", dbdir, db_strerror(r));
     return MYDB_IOERROR;
@@ -285,9 +289,6 @@ static int myarchive(const char **fnames, const char *dirname)
     const char **fname;
     char dstname[1024], *dp;
 
-    strcpy(dstname, dirname);
-    dp = dstname + strlen(dstname);
-
     /* Get the list of log files to remove. */
     r = log_archive(dbenv, &list, DB_ARCH_ABS, NULL);
     if (r) {
@@ -308,6 +309,11 @@ static int myarchive(const char **fnames, const char *dirname)
 	free (begin);
     }
 
+    if (!dirname) return 0;
+
+    strcpy(dstname, dirname);
+    dp = dstname + strlen(dstname);
+
     /* Get the list of database files to archive. */
     /* XXX  Should we do this, or just use the list given to us? */
     r = log_archive(dbenv, &list, DB_ARCH_ABS | DB_ARCH_DATA, NULL);
