@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/shared/config.c,v 1.3 2008/05/29 10:10:25 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/shared/config.c,v 1.4 2008/06/24 14:40:49 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -168,7 +168,7 @@ struct config *config_create(void)
     config->fatal_dump_core = NIL;
 
     config->template_path = "../templates";
-    config->template_set  = "html4";
+    config->template_set  = "xhtml_strict";
     config->template_use_compiled = T;
 
     config->prayer_user = NIL;
